package com.doc.biz.controller;

import com.doc.biz.domain.DocTransfer;
import com.doc.biz.service.IDocTransferService;
import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.core.page.TableDataInfo;
import com.doc.common.enums.BusinessType;
import com.doc.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 文件传输Controller
 *
 * @author wukai
 * @date 2023-08-15
 */
@Api(tags = "文件传输")
@RestController
@RequestMapping("/biz/transfer")
public class DocTransferController extends BaseController {
    @Resource
    private IDocTransferService docTransferService;

    /**
     * 查询文件传输列表
     */
    @ApiOperation("查询文件传输列表")
    //@PreAuthorize("@ss.hasPermi('biz:transfer:list')")
    @GetMapping("/list")
    public TableDataInfo list(DocTransfer docTransfer) {
        startPage();
        List<DocTransfer> list = docTransferService.selectDocTransferList(docTransfer);
        return getDataTable(list);
    }

    /**
     * 导出文件传输列表
     */
    @ApiOperation("导出文件传输列表")
    //@PreAuthorize("@ss.hasPermi('biz:transfer:export')")
    @Log(title = "文件传输", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DocTransfer docTransfer) {
        List<DocTransfer> list = docTransferService.selectDocTransferList(docTransfer);
        ExcelUtil<DocTransfer> util = new ExcelUtil<DocTransfer>(DocTransfer.class);
        util.exportExcel(response, list, "文件传输数据");
    }

    /**
     * 获取文件传输详细信息
     */
    @ApiOperation("获取文件传输详细信息")
    //@PreAuthorize("@ss.hasPermi('biz:transfer:query')")
    @GetMapping(value = "/{tranId}")
    public AjaxResult getInfo(@PathVariable("tranId") Long tranId) {
        return success(docTransferService.selectDocTransferByTranId(tranId));
    }

    /**
     * 新增文件传输
     */
    @ApiOperation("新增文件传输")
    //@PreAuthorize("@ss.hasPermi('biz:transfer:add')")
    @Log(title = "文件传输", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DocTransfer docTransfer) {
        return toAjax(docTransferService.insertDocTransfer(docTransfer));
    }

    /**
     * 修改文件传输
     */
    @ApiOperation("修改文件传输")
    //@PreAuthorize("@ss.hasPermi('biz:transfer:edit')")
    @Log(title = "文件传输", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DocTransfer docTransfer) {
        return toAjax(docTransferService.updateDocTransfer(docTransfer));
    }

    /**
     * 删除文件传输
     */
    @ApiOperation("删除文件传输")
    //@PreAuthorize("@ss.hasPermi('biz:transfer:remove')")
    @Log(title = "文件传输", businessType = BusinessType.DELETE)
    @DeleteMapping("/{tranIds}")
    public AjaxResult remove(@PathVariable Long[] tranIds) {
        return toAjax(docTransferService.deleteDocTransferByTranIds(tranIds));
    }
}
