package com.doc.biz.service;

import com.doc.biz.domain.DocSpace;
import com.doc.common.core.domain.entity.SysDept;
import com.doc.common.core.domain.entity.SysUser;

import java.util.List;

/**
 * 文档空间管理Service接口
 *
 * @author wukai
 * @date 2023-08-15
 */
public interface IDocSpaceService {
    /**
     * 查询文档空间管理
     *
     * @param spaceId 文档空间管理主键
     * @return 文档空间管理
     */
    public DocSpace selectDocSpaceBySpaceId(Long spaceId);

    /**
     * 根据spaceId更新空间使用情况
     *
     * @param spaceId 空间ID
     */
    void updateUsedCap(Long spaceId);

    /**
     * 查询文档空间管理列表
     *
     * @param docSpace 文档空间管理
     * @return 文档空间管理集合
     */
    public List<DocSpace> selectDocSpaceList(DocSpace docSpace);

    /**
     * 根据空间类型查询目录
     *
     * @param type 空间类型
     * @return 文档空间管理集合
     */
    DocSpace selectDocSpaceListByType(String type);

    /**
     * 根据用户ID获取空间信息
     *
     * @param userId 用户ID
     * @return
     */
    List<DocSpace> getSpaceByUser(Long userId);

    /**
     * 新增文档空间管理
     *
     * @param docSpace 文档空间管理
     * @return 结果
     */
    public int insertDocSpace(DocSpace docSpace);

    /**
     * 修改文档空间管理
     *
     * @param docSpace 文档空间管理
     * @return 结果
     */
    public int updateDocSpace(DocSpace docSpace);

    /**
     * 批量删除文档空间管理
     *
     * @param spaceIds 需要删除的文档空间管理主键集合
     * @return 结果
     */
    public int deleteDocSpaceBySpaceIds(Long[] spaceIds);

    /**
     * 删除文档空间管理信息
     *
     * @param spaceId 文档空间管理主键
     * @return 结果
     */
    public int deleteDocSpaceBySpaceId(Long spaceId);

    /**
     * 初始化用户空间
     *
     * @param user 用户实体
     */
    void initUserSpace(SysUser user);

    /**
     * 初始化部门空间
     *
     * @param dept 部门实体
     */
    void initDeptSpace(SysDept dept);

    /**
     * 增加容量
     *
     * @param spaceId   空间ID
     * @param expandCap 容量大小
     */
    void addCap(Long spaceId, Long expandCap);
}
