package com.doc.biz.service.impl;

import com.doc.biz.domain.DocActor;
import com.doc.biz.domain.DocInfo;
import com.doc.biz.mapper.DocActorMapper;
import com.doc.biz.service.IDocActorService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 文档协作Service业务层处理
 *
 * @author wukai
 * @date 2023-09-18
 */
@Service
public class DocActorServiceImpl implements IDocActorService {
    @Resource
    private DocActorMapper docActorMapper;

    /**
     * 查询文档协作
     *
     * @param docId 文档协作主键
     * @return 文档协作
     */
    @Override
    public DocActor selectDocActorByDocId(Long docId) {
        return docActorMapper.selectDocActorByDocId(docId);
    }

    /**
     * 查询文档协作列表
     *
     * @param docActor 文档协作
     * @return 文档协作
     */
    @Override
    public List<DocActor> selectDocActorList(DocActor docActor) {
        return docActorMapper.selectDocActorList(docActor);
    }

    /**
     * 新增文档协作
     *
     * @param docActor 文档协作
     * @return 结果
     */
    @Override
    public int insertDocActor(DocActor docActor) {
        return docActorMapper.insertDocActor(docActor);
    }

    /**
     * 修改文档协作
     *
     * @param docActor 文档协作
     * @return 结果
     */
    @Override
    public int updateDocActor(DocActor docActor) {
        return docActorMapper.updateDocActor(docActor);
    }

    /**
     * 批量删除文档协作
     *
     * @param docIds 需要删除的文档协作主键
     * @return 结果
     */
    @Override
    public int deleteDocActorByDocIds(Long[] docIds) {
        return docActorMapper.deleteDocActorByDocIds(docIds);
    }

    /**
     * 删除文档协作信息
     *
     * @param docId 文档协作主键
     * @return 结果
     */
    @Override
    public int deleteDocActorByDocId(Long docId) {
        return docActorMapper.deleteDocActorByDocId(docId);
    }

    /**
     * 我发起的
     *
     * @param userId 用户ID
     * @return 结果
     */
    @Override
    public List<DocInfo> initiationList(Long userId) {
        return docActorMapper.initiationList(userId);
    }

    /**
     * 我参与的
     *
     * @param userId 用户ID
     * @return 结果
     */
    @Override
    public List<DocInfo> participationList(Long userId) {
        return docActorMapper.participationList(userId);
    }
}
