package com.doc.chat.domain;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.doc.biz.domain.DocInfo;
import com.doc.common.annotation.Excel;
import com.doc.common.core.domain.BaseEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

/**
 * 聊天消息管理对象 chat_msg
 *
 * @author wukai
 * @date 2023-08-25
 */
@Data
@ApiModel(value = "ChatMsg", description = "聊天消息管理")
public class ChatMsg extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 消息ID
     */
    @ApiModelProperty("消息ID")
    @TableId
    private Long msgId;

    /**
     * 发送方用户ID
     */
    @ApiModelProperty("发送方用户ID")
    @Excel(name = "发送方用户ID")
    private Long fromId;
    /**
     * 发送方用户姓名
     */
    @ApiModelProperty("发送方用户姓名")
    @Excel(name = "发送方用户姓名")
    @TableField(exist = false)
    private String fromName;
    /**
     * 发送方用户头像
     */
    @ApiModelProperty("发送方用户头像")
    @TableField(exist = false)
    private String fromAvatar;
    /**
     * 接受方用户ID
     */
    @ApiModelProperty("接收方用户ID")
    @Excel(name = "接收方用户ID")
    private Long toId;
    /**
     * 接收方用户姓名
     */
    @ApiModelProperty("接收方用户姓名")
    @TableField(exist = false)
    private String toName;
    /**
     * 接收方用户头像
     */
    @ApiModelProperty("接收方用户头像")
    @TableField(exist = false)
    private String toAvatar;

    /**
     * 消息类型; 1.文件 2.聊天
     */
    @ApiModelProperty("消息类型; 1.文件 2.聊天")
    @Excel(name = "消息类型; 1.文件 2.聊天")
    private String msgType;

    /**
     * 消息内容
     */
    @ApiModelProperty("消息内容")
    @Excel(name = "消息内容")
    private String content;

    /**
     * ID索引
     */
    @ApiModelProperty("ID索引")
    @Excel(name = "ID索引")
    private String idIndex;

    /**
     * 文件列表
     */
    @ApiModelProperty("文件信息")
    @TableField(exist = false)
    private DocInfo file;

    @Override
    public String toString() {
        return new ToStringBuilder(this, ToStringStyle.MULTI_LINE_STYLE)
                .append("msgId", getMsgId())
                .append("fromId", getFromId())
                .append("toId", getToId())
                .append("msgType", getMsgType())
                .append("content", getContent())
                .append("idIndex", getIdIndex())
                .append("createTime", getCreateTime())
                .toString();
    }
}
